package ru.crystals.api.examples;

import org.slf4j.Logger;
import ru.crystals.ERPIntegration.discounts.model.xml.imp.AdvertisingActionType;
import ru.crystals.ERPIntegration.discounts.model.xml.imp.AdvertisingActionsType;
import ru.crystals.pos.api.ext.loyal.dto.AdvertisingActionProviderResult;
import ru.crystals.pos.api.plugin.AdvertisingActionProviderPlugin;
import ru.crystals.pos.spi.annotation.Inject;
import ru.crystals.pos.spi.annotation.POSPlugin;
import ru.crystals.pos.spi.receipt.Receipt;

import javax.annotation.PostConstruct;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBElement;
import java.util.Collections;
import java.util.List;

/**
 * Простейший пример плагина поставщика рекламных акций.
 */
@POSPlugin(id="ru.crystals.api.example.advertising.action.provider.plugin")
public class AdvertisingActionProviderExample implements AdvertisingActionProviderPlugin {

    @Inject
    private Logger logger;

    @PostConstruct
    public void init() {
        logger.info("{} started", this.getClass());
    }

    @Override
    public AdvertisingActionProviderResult getAdvertisingActions(Receipt receipt) {
        logger.info("getAdvertisingActions called");
        return new AdvertisingActionProviderResult(getActions());
    }

    private List<AdvertisingActionType> getActions() {
        try {
            JAXBContext context = JAXBContext.newInstance(AdvertisingActionsType.class.getPackage().getName());
            JAXBElement<AdvertisingActionsType> element = (JAXBElement<AdvertisingActionsType>) context.createUnmarshaller()
                    .unmarshal(getClass().getResourceAsStream("/provider-actions.xml"));
            return element.getValue().getAdvertisingAction();
        } catch (Exception e) {
            logger.error("getActions failed!", e);
            return Collections.emptyList();
        }
    }
}
