package ru.crystals.pos.api.card;

import ru.crystals.pos.spi.receipt.Address;
import ru.crystals.pos.spi.receipt.CardHolder;
import ru.crystals.pos.spi.receipt.ReceiptFeedbackType;
import ru.crystals.pos.spi.receipt.Sex;

import java.util.Date;
import java.util.HashSet;
import java.util.Set;

/**
 * Сущность, описывающая владельца карты.
 */
public class CardHolderEntity implements CardHolder {

    private String id;

    private String firstName;

    private String lastName;

    private String middleName;

    private Address clientAddress;

    private String phone;

    private String email;

    /**
     * Дата рождения
     */
    private Date birthDate;

    /**
     * Пол
     */
    private Sex sex;

    /**
     * Женат/замужем?
     */
    private Boolean marital;

    /**
     * Признак заполненности анкеты
     */
    private boolean completed;

    /**
     * Способы, которыми необходимо оповестить клиента о совершенной покупке
     */
    private Set<ReceiptFeedbackType> receiptFeedbackTypes;

    /**
     * Конструктор 
     */
    public CardHolderEntity() {
        super();
    }
    
    /**
     * Конструктор
     * @param id идентификатор клиента
     * @param firstName имя
     * @param lastName фамилия
     * @param middleName отчество
     */
    public CardHolderEntity(String id, String firstName, String lastName, String middleName) {
        super();
        this.id = id;
        this.firstName = firstName;
        this.lastName = lastName;
        this.middleName = middleName;
    }

    @Override
    public String getId() {
        return id;
    }

    /**
     * Установить идентификатор владельца карты
     * @param id идентификатор
     */
    public void setId(String id) {
        this.id = id;
    }

    @Override
    public String getFirstName() {
        return firstName;
    }

    /**
     * Установить имя владельца карты
     * @param firstName имя
     */
    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }

    @Override
    public String getLastName() {
        return lastName;
    }

    /**
     * Установить фамилию владельца карты
     * @param lastName фамилия
     */
    public void setLastName(String lastName) {
        this.lastName = lastName;
    }

    @Override
    public String getMiddleName() {
        return middleName;
    }

    /**
     * Установить отчество владельца карты
     * @param middleName отчество
     */
    public void setMiddleName(String middleName) {
        this.middleName = middleName;
    }

    @Override
    public Address getClientAddress() {
        return clientAddress;
    }

    public void setClientAddress(Address clientAddress) {
        this.clientAddress = clientAddress;
    }

    @Override
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    @Override
    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    @Override
    public Date getBirthDate() {
        return birthDate;
    }

    public void setBirthDate(Date birthDate) {
        this.birthDate = birthDate;
    }

    @Override
    public Sex getSex() {
        return sex;
    }

    public void setSex(Sex sex) {
        this.sex = sex;
    }

    @Override
    public Boolean getMarital() {
        return marital;
    }

    public void setMarital(Boolean marital) {
        this.marital = marital;
    }

    @Override
    public boolean isCompleted() {
        return completed;
    }

    public void setCompleted(boolean completed) {
        this.completed = completed;
    }

    @Override
    public Set<ReceiptFeedbackType> getReceiptFeedbackTypes() {
        if (receiptFeedbackTypes == null) {
            receiptFeedbackTypes = new HashSet<>();
        }
        return receiptFeedbackTypes;
    }

    @Override
    public String toString() {
        return "CardHolderEntity{" +
                "id='" + id + '\'' +
                ", firstName='" + firstName + '\'' +
                ", lastName='" + lastName + '\'' +
                ", middleName='" + middleName + '\'' +
                '}';
    }
}
