package ru.crystals.pos.api.ext.loyal.dto;

import ru.crystals.pos.api.plugin.goods.NewLineItem;
import ru.crystals.pos.spi.Action;

import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.Map;

/**
 * Результат обработки плагином события добавления товара в чек.
 */
public class AddForSaleResult {
    /**
     * Сущность для передачи кассе данных о новой позиции чека.
     */
    private NewLineItem newLineItem;

    /**
     * Действия, которые нужно произвести, если добавление новой позиции пройдет успешно.
     */
    private Collection<Action> actionsToTake = new LinkedList<>();

    /**
     * Дополнительные данные в формате &lt;ключ, значение&gt;, которые будут добавлены в чек.
     */
    private Map<String, String> extendedReceiptAttributes = new HashMap<>();

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link AddForSaleResult}.
     */
    public AddForSaleResult() {
        // Nop
    }

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link AddForSaleResult}
     *
     * @param newLineItem сущность для передачи кассе данных о новой позиции чека
     */
    public AddForSaleResult(NewLineItem newLineItem) {
        this.newLineItem = newLineItem;
    }

    /**
     * Возвращает сущность для передачи кассе данных о новой позиции чека.
     *
     * @return сущность для передачи кассе данных о новой позиции чека.
     */
    public NewLineItem getNewLineItem() {
        return newLineItem;
    }

    /**
     * Устанавливает сущность для передачи кассе данных о новой позиции чека.
     *
     * @param newLineItem сущность для передачи кассе данных о новой позиции чека
     */
    public void setNewLineItem(NewLineItem newLineItem) {
        this.newLineItem = newLineItem;
    }

    /**
     * Возвращает коллекцию действий, которые нужно произвести, если добавление пройдет успешно.
     *
     * @return коллекция действий
     *
     * @apiNote
     * Важно знать:<br>
     * 1. Каждый Action атомарен и не влияет на выполнение других<br>
     * 2. Выполнение не гарантируется и не влияет на добавление товара в чек
     */
    public Collection<Action> getActionsToTake() {
        return actionsToTake;
    }

    /**
     * Возвращает дополнительные данные в формате &lt;ключ, значение&gt;, которые будут добавлены в чек.
     *
     * @return коллекция ключей и значений
     */
    public Map<String, String> getExtendedReceiptAttributes() {
        return extendedReceiptAttributes;
    }

    @Override
    public String toString() {
        return "AddForSaleResult{" +
                "newLineItem=" + newLineItem +
                ", actionsToTake=" + actionsToTake +
                ", extendedReceiptAttributes=" + extendedReceiptAttributes +
                '}';
    }
}
