package ru.crystals.pos.api.ext.loyal.dto;


import ru.crystals.ERPIntegration.discounts.model.xml.imp.AdvertisingActionType;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.List;

/**
 * Структура, хранящая результат запроса от внешней системы рекламных акций для расчета скидок в текущемчеке.
 *
 * @since 0.0.59
 */
public class AdvertisingActionProviderResult {
    private List<AdvertisingActionType> advertisingActions;

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link AdvertisingActionProviderResult}.
     */
    public AdvertisingActionProviderResult() {
        // Конструктор без аргументов просто на всякий случай.
        advertisingActions = new ArrayList<>();
    }

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link AdvertisingActionProviderResult}.
     *
     * @param actions массив рекламных акций, которые нужно передать кассе для расчета скидок в текущем чеке.
     */
    public AdvertisingActionProviderResult(AdvertisingActionType... actions) {
        this();
        advertisingActions.addAll(Arrays.asList(actions));
    }

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link AdvertisingActionProviderResult}.
     *
     * @param actions коллекцию рекламных акций, которые нужно передать кассе для расчета скидок в текущем чеке.
     */
    public AdvertisingActionProviderResult(Collection<AdvertisingActionType> actions) {
        this();
        advertisingActions.addAll(actions);
    }

    /**
     * Возвращает список рекламных акций внешней системы, которые должны участвовать в расчете скидок текущего чека.
     *
     * @return список рекламных акций для участия в расчете или пустой список, если таких нет.
     */
    public List<AdvertisingActionType> getAdvertisingActions() {
        return advertisingActions;
    }
}
