package ru.crystals.pos.api.ext.loyal.dto;

import java.util.HashMap;
import java.util.Map;

/**
 * Результат обработки плагином события удаления товара из чека.
 */
public class RemoveFromSaleResult {
    /**
     * Флаг, определяющий, разрешил ли плагин удаление позиции из чека. true если разрешил и false в противном случае.
     */
    private boolean removeAllowed = false;

    /**
     * Дополнительные данные в формате &lt;ключ, значение&gt;, которые будут добавлены в чек.
     */
    private Map<String, String> extendedReceiptAttributes = new HashMap<>();

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link RemoveFromSaleResult}.
     */
    public RemoveFromSaleResult() {
        // Nop
    }

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link RemoveFromSaleResult}
     *
     * @param removeAllowed флаг, определяющий, разрешил ли плагин удаление позиции из чека.
     *                      true если разрешил и false в противном случае.
     */
    public RemoveFromSaleResult(boolean removeAllowed) {
        this.removeAllowed = removeAllowed;
    }

    /**
     * Возвращает флаг, определяющий, разрешил ли плагин удаление позиции из чека. true если разрешил и false в противном случае.
     *
     * @return
     */
    public boolean isRemoveAllowed() {
        return removeAllowed;
    }

    /**
     * Устанавливает флаг, определяющий, разрешил ли плагин удаление позиции из чека. true если разрешил и false в противном случае.
     *
     * @param removeAllowed значение флага разрешения удаления позиции из чека
     */
    public void setRemoveAllowed(boolean removeAllowed) {
        this.removeAllowed = removeAllowed;
    }

    /**
     * Возвращает дополнительные данные в формате &lt;ключ, значение&gt;, которые будут добавлены в чек.
     *
     * @return коллекция ключей и значений
     */
    public Map<String, String> getExtendedReceiptAttributes() {
        return extendedReceiptAttributes;
    }

    @Override
    public String toString() {
        return "RemoveFromSaleResult{" +
                "removeAllowed=" + removeAllowed +
                ", extendedReceiptAttributes=" + extendedReceiptAttributes +
                '}';
    }
}
