package ru.crystals.pos.api.plugin;

import ru.crystals.pos.api.ext.loyal.dto.AdvertisingAction;
import ru.crystals.pos.spi.receipt.Receipt;

/**
 * Плагин условия применения рекламной акции.  Всякая рекламная акция состоит из условий применения акции и результатов
 * применения акции. Чтобы рекламная акция повлияла на чек, необходимо, чтобы выполнились её условия.
 * Данный тип плагина предназначен для разрешения или запрещения применения к содержимому чека рекламной акции при расчете скидок.<br>
 * Следует учитывать, что при расчете скидок условие применения акции может быть проверено более одного раза и, по возможности,
 * не выполнять длительных операций (например, обращения во внешнюю систему) при проверке условия, потому что это замедляет расчет скидок
 * и уменьшает скорость обслуживания клиента.
 * @since 0.0.47
 */
public interface AdvertisingActionConditionPlugin {

    /**
     * Данный метод вызывается кассой перед началом расчета скидок.
     * @param receipt чек, для которого собирается выполниться расчет скидок.
     */
    default void onDiscountCalculationStarted(Receipt receipt) {}

    /**
     * Проверяет условие выполнения рекламной акции при расчете скидок.
     * @param action рекламная акция, которая содержит условие, обрабатываемое данным плагином.
     * @param receipt чек, для которого выполняется расчет скидок.
     * @return true если условие выполняется и false в противном случае.
     */
    boolean isConditionExecuted(AdvertisingAction action, Receipt receipt);

    /**
     * Данный метод вызывается кассой по окончанию расчета скидок.
     * @param receipt чек, для которого расчитывались скидки.
     */
    default void onDiscountCalculationFinished(Receipt receipt){};
}
