package ru.crystals.pos.api.plugin;

import ru.crystals.pos.api.plugin.excise.validation.ExciseValidationResponse;
import ru.crystals.pos.api.plugin.excise.validation.SearchInfoResponse;
import ru.crystals.pos.spi.plugin.FiscalizationListener;
import ru.crystals.pos.spi.plugin.excise.validation.ExciseValidationRequest;

/**
 * Интерфейс плагина проверки акцизной марки для продажи и возврата товара
 */
public interface ExciseValidationPlugin extends FiscalizationListener {

    /**
     * Проверка акцизной марки товара на возможность продажи.
     * @param exciseValidationRequest прараметры запроса проверки
     * @return {@link ExciseValidationResponse} - результат проверки
     */
    ExciseValidationResponse validateExciseForSale(ExciseValidationRequest exciseValidationRequest);

    /**
     * Проверка акцизной марки товара на возможность возврата.
     * @param exciseValidationRequest прараметры запроса проверки
     * @return {@link ExciseValidationResponse} - результат проверки
     */
    ExciseValidationResponse validateExciseForRefund(ExciseValidationRequest exciseValidationRequest);

    /**
     * Поиск информации о товаре по акцизной марке
     * Метод default т.к. необязателен для реализации во всех плагинах, имплементирующих этот
     * @param excise - Строковое представление акцизной марки для поиска
     * @return {@link SearchInfoResponse} - результат поиска
     */
    default SearchInfoResponse searchInfoByExcise(String excise) {
        return null;
    }

}
