package ru.crystals.pos.api.plugin.excise.validation;

/**
 * Результат проверки акцизной марки (АМ) при продаже или возврате товара
 */
public class ExciseValidationResponse {

    private boolean operationAllowed;

    private String message;

    /**
     * Признак попытки осуществить проверку АМ в режиме "offline"
     */
    private boolean offline = true;

    /**
     * Конструктор по умолчанию.<br>
     * Продажа/возврат акцизной марки разрешена.
     */
    public ExciseValidationResponse() {
        this.operationAllowed = true;
        this.message = null;
    }

    /**
     * Конструктор результата проверки.
     *
     * @param operationAllowed true действие (продажа/возврат) разрешено, false - запрещено
     * @param message          сообщение, которое необходимо отобразить на кассе при отрицательном результате проверки
     */
    public ExciseValidationResponse(boolean operationAllowed, String message) {
        this.operationAllowed = operationAllowed;
        this.message = message;
    }

    /**
     * Конструктор результата проверки.
     *
     * @param operationAllowed true действие (продажа/возврат) разрешено, false - запрещено
     * @param message          сообщение, которое необходимо отобразить на кассе при отрицательном результате проверки
     * @param offline          признак попытки осуществить проверку АМ в режиме "offline"
     */
    public ExciseValidationResponse(boolean operationAllowed, String message, boolean offline) {
        this(operationAllowed, message);
        this.offline = offline;
    }

    /**
     * Значение признака возможности осуществления действия с товаром (продажа/возврат) в результате валидации АМ.
     *
     * @return true - операция (продажа/возврат) роазрешена, false - запрещена
     */
    public boolean isOperationAllowed() {
        return operationAllowed;
    }

    /**
     * Установить признак возможности осуществления действия с товаром (продажа/возврат) в результате валидации АМ.<p>
     * Значения признака: true - операция (продажа/возврат) роазрешена, false - запрещена.
     * @param operationAllowed значение признака
     */
    public void setOperationAllowed(boolean operationAllowed) {
        this.operationAllowed = operationAllowed;
    }

    /**
     * Сообщение пользователю, которое будет отображено при отрицательном результате проверки.
     * @return текст сообщения
     */
    public String getMessage() {
        return message;
    }

    /**
     * Установить сообщение пользователю, которое будет отображено при отрицательном результате проверки.
     * @param message текст сообщения
     */
    public void setMessage(String message) {
        this.message = message;
    }

    /**
     * Признак попытки осуществить проверку АМ в режиме "offline"
     */
    public boolean isOffline() {
        return offline;
    }

    /**
     * Признак попытки осуществить проверку АМ в режиме "offline"
     */
    public void setOffline(boolean offline) {
        this.offline = offline;
    }

    @Override
    public String toString() {
        return "ExciseValidationResponse{" +
                "operationAllowed=" + operationAllowed +
                ", message='" + message + '\'' +
                ", offline=" + offline +
                '}';
    }
}
