package ru.crystals.pos.api.plugin.function;

import java.math.BigDecimal;

/**
 * Результат вызова функционального плагина поиска товара
 */
public class SearchProductResult implements FunctionResult {

    /**
     * Данные для поиска товара на кассе
     */
    private String data;

    /**
     * Тип данных (ШК, артикул и т.п.)
     */
    private SearchProductDataType dataType;

    /**
     * Количество в тысячных долях единиц (т.е. 1000 == 1 шт. (или 1 кг.), 100 == 100 гр.)
     */
    private Long quantity;

    /**
     * Цена (&gt;= 0, scale = 2)
     */
    private BigDecimal price;

    public SearchProductResult(String data, SearchProductDataType dataType) {
        this(data, dataType, null, null);
    }

    public SearchProductResult(String data, SearchProductDataType dataType, Long quantity, BigDecimal price) {
        this.data = data;
        this.dataType = dataType;
        this.quantity = quantity;
        this.price = price;
    }

    @Override
    public FunctionResultType getType() {
        return FunctionResultType.SEARCH_PRODUCT;
    }

    public String getData() {
        return data;
    }

    public SearchProductDataType getDataType() {
        return dataType;
    }

    public Long getQuantity() {
        return quantity;
    }

    public BigDecimal getPrice() {
        return price;
    }
}
