package ru.crystals.pos.api.plugin.function.dto;

import ru.crystals.pos.api.ext.loyal.dto.Slip;
import ru.crystals.pos.spi.receipt.ReceiptType;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Данные для формирования чека на кассе.
 * Используем в качестве полезной нагрузки в {@link ru.crystals.pos.api.plugin.function.CreateReceiptResult}
 */
public class Receipt {

    /**
     * Тип чека
     */
    private final ReceiptType type;

    /**
     * Позиции
     */
    private List<Position> positions;

    /**
     * Оплаты
     */
    private List<Payment> payments;

    /**
     * Признак необходимости контролировать порядок вызова оплат на кассе
     */
    private boolean controlOrderPayments;

    /**
     * Сумма чека
     */
    private BigDecimal amount;

    /**
     * Документы для печати
     */
    private List<Slip> slips;

    /**
     * Признак "Разрешено редактирование чека"
     * Если true - разрешено добавление, удаление. Изменение кол-ва и цены позиций зависят от {@link Position#isEditable()}
     * Если false - полный запрет
     */
    private boolean editable;

    /**
     * Дополнительные данные чека &lt;ключ, значение&gt;
     */
    private Map<String, String> data;

    public Receipt(ReceiptType type) {
        this.type = type;
    }

    public ReceiptType getType() {
        return type;
    }

    public List<Position> getPositions() {
        if (positions == null) {
            positions = new ArrayList<>();
        }
        return positions;
    }

    public void setPositions(List<Position> positions) {
        this.positions = positions;
    }

    public List<Payment> getPayments() {
        if (payments == null) {
            payments = new ArrayList<>();
        }
        return payments;
    }

    public void setPayments(List<Payment> payments) {
        this.payments = payments;
    }

    public boolean isControlOrderPayments() {
        return controlOrderPayments;
    }

    public void setControlOrderPayments(boolean controlOrderPayments) {
        this.controlOrderPayments = controlOrderPayments;
    }

    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }

    public List<Slip> getSlips() {
        if (slips == null) {
            slips = new ArrayList<>();
        }
        return slips;
    }

    public void setSlips(List<Slip> slips) {
        this.slips = slips;
    }

    public boolean isEditable() {
        return editable;
    }

    public void setEditable(boolean editable) {
        this.editable = editable;
    }

    public Map<String, String> getData() {
        if (data == null) {
            data = new HashMap<>();
        }
        return data;
    }
}
