package ru.crystals.pos.api.plugin.techprocess;

import ru.crystals.pos.api.ext.loyal.dto.Slip;
import ru.crystals.pos.api.plugin.techprocess.dto.Declaration;
import ru.crystals.pos.spi.feedback.Feedback;
import ru.crystals.pos.spi.receipt.LineItem;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Результат интерактивного взаимодействия с плагином тех. процесса.
 */
public class InterceptionResult {

    private Map<String, String> receiptExtendedAttributesMap;

    private Map<LineItem, List<Slip>> lineItemsSlipsMap;

    private Map<LineItem, List<Declaration>> lineItemsDeclarationMap;

    private Map<LineItem, Map<String, String>> positionAttributeMap;

    private String errorMessage;

    private Feedback feedback;

    /**
     * Мапа расширенных атрибутов, которыми плагин тех. процесса может наградить чек.<br>
     * Заполняется плагином в случае, если он хочет добавить к чеку какие-то дополнительные параметры.
     * @return мапу расширенных атрибутов чека или пустую мапу, если таких нет.
     */
    public Map<String, String> getReceiptExtendedAttributesMap() {
        if (receiptExtendedAttributesMap == null) {
            receiptExtendedAttributesMap = new HashMap<>();
        }
        return receiptExtendedAttributesMap;
    }

    /**
     * Мапа слипов, которые плагин тех. процесса добавил к позициям чека.
     * @return мапа слипов или пустая коллекция, если слипов нет.
     */
    public Map<LineItem, List<Slip>> getLineItemsSlipsMap() {
        if (lineItemsSlipsMap == null) {
            lineItemsSlipsMap = new HashMap<>();
        }
        return lineItemsSlipsMap;
    }

    /**
     * Данные по ГТД (Грузовая таможенная декларация) для позиций чека.
     * Заполняется плагином при получении этих данных из внешнего сервиса.
     * Обрабатывается в стадии {@link InterceptedStage#SUBTOTAL_START}
     * Если по одной позиции получено несколько ГТД, то позиция будет разбита по кол-ву ГТД.
     * @return данные ГТД
     */
    public Map<LineItem, List<Declaration>> getLineItemsDeclarationMap() {
        if (lineItemsDeclarationMap == null) {
            lineItemsDeclarationMap = new HashMap<>();
        }

        return lineItemsDeclarationMap;
    }

    /**
     * Мапу расширенных атрибутов позиций, которые плагин тех. процесса добавил к позициям чека.
     *
     * @return мапа расширенных атрибутов позиций
     * @since 1.2.0
     */
    public Map<LineItem, Map<String, String>> getPositionAttributeMap() {
        if (positionAttributeMap == null) {
            positionAttributeMap = new HashMap<>();
        }

        return positionAttributeMap;
    }

    /**
     * Собщение об ошибке, если в процессе работы плагина возникли такие ошибки, сообщения о которых нужно передать в процессинг.
     * @return сообщение об ошибке
     */
    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    /**
     * Некая полезная нагрузка, возвращаемая плагином для последующей повторной отправки, если плагин не смог отправить данные.
     * @return null, если отправка данных плагином удалась. Feedback, если отправка не удалась и необходимо выполнять периодические попытки отправки.
     */
    public Feedback getFeedback() {
        return feedback;
    }

    public void setFeedback(Feedback feedback) {
        this.feedback = feedback;
    }

    @Override
    public String toString() {
        return "InterceptionResult{" +
                "receiptExtendedAttributesMap=" + receiptExtendedAttributesMap +
                ", lineItemsSlipsMap=" + lineItemsSlipsMap +
                ", lineItemsDeclarationMap=" + lineItemsDeclarationMap +
                ", positionAttributeMap=" + positionAttributeMap +
                ", errorMessage='" + errorMessage + '\'' +
                ", feedback=" + feedback +
                '}';
    }
}
