package ru.crystals.pos.api.plugin.techprocess.dto;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;

/**
 * Данные ГТД (Грузовая таможенная декларация) или РНПТ (регистрационный номер партии)
 */
public class Declaration {

    /**
     * Тип документа
     */
    private DeclarationType type;
    
    /**
     * Артикул товара
     */
    private String item;

    /**
     * Количество товара
     */
    private BigDecimal quantity;

    /**
     * Номер документа
     */
    private String declarationNumber;

    /**
     * Код страны происхождения товара согласно Общероссийскому Классификатору Стран Мира (ОКСМ)
     */
    private String rccw;

    /**
     * Страна происхождения
     */
    private String country;

    /**
     * Дополнительные параметры, связанные с ГТД/РНПТ, которые должны быть сохранены в плагинных свойствах позиции
     */
    private Map<String, String> extData;

    public String getItem() {
        return item;
    }

    public BigDecimal getQuantity() {
        return quantity;
    }

    public String getDeclarationNumber() {
        return declarationNumber;
    }

    public String getRccw() {
        return rccw;
    }

    public String getCountry() {
        return country;
    }

    public DeclarationType getType() {
        return type;
    }

    public Map<String, String> getExtData() {
        if (extData == null) {
            extData = new HashMap<>();
        }
        return extData;
    }

    @Override
    public String toString() {
        return "Declaration{" +
                "type=" + type +
                ", item='" + item + '\'' +
                ", quantity=" + quantity +
                ", declarationNumber='" + declarationNumber + '\'' +
                ", rccw='" + rccw + '\'' +
                ", country='" + country + '\'' +
                '}';
    }

    public static Builder builder() {
        return new Declaration().new Builder();
    }

    public class Builder {

        public Builder type(DeclarationType type) {
            Declaration.this.type = type;
            return this;
        }

        public Builder item(String item) {
            Declaration.this.item = item;
            return this;
        }

        public Builder quantity(BigDecimal quantity) {
            Declaration.this.quantity = quantity;
            return this;
        }

        public Builder declarationNumber(String declarationNumber) {
            Declaration.this.declarationNumber = declarationNumber;
            return this;
        }

        public Builder rccw(String rccw) {
            Declaration.this.rccw = rccw;
            return this;
        }

        public Builder country(String country) {
            Declaration.this.country = country;
            return this;
        }

        public Builder extData(Map<String, String> extData) {
            Declaration.this.extData = extData;
            return this;
        }

        public Declaration build() {
            return Declaration.this;
        }
    }
}
