package ru.crystals.pos.spi.plugin.excise.validation;

import ru.crystals.pos.spi.MarkedProductType;
import ru.crystals.pos.spi.receipt.Merchandise;
import ru.crystals.pos.spi.receipt.Receipt;

/**
 * Интерфейс запроса проверки акцизной марки
 */
public interface ExciseValidationRequest {

    /**
     * Акцизная марка
     *
     * @return строковое представление акцизной марки
     */
    String getExcise();

    /**
     * Штрихкод товара
     *
     * @return строковое представление штрихкода товара
     */
    String getBarcode();

    /**
     * Тип маркируемого товара
     * @return тип маркируемого товара
     * @since 0.0.63
     */
    MarkedProductType getProductType();

    /**
     * Текущий чек продажи/возврата, в который будет добавляться позиция товара
     *
     * @return чек - {@link Receipt}
     */
    Receipt getReceipt();

    /**
     * Артикул товара, подлежащего валидации
     *
     * @return артикул товара
     * @since 0.0.67
     */
    default String getItem() {
        return null;
    }

    /**
     * Товар, подлежащий валидации
     * ШК и артикул проверяемого товара получаем методами getBarcode() и getItem() а не из товара.
     * Особенно это касается акцизного алкоголя т.к. товар может быть набором, а проверяется компонент набора.
     *
     * @return товар
     * @since 0.0.104
     */
    default Merchandise getMerchandise() {
        return null;
    }

}
