package ru.crystals.pos.spi.plugin.goods;


import ru.crystals.pos.spi.receipt.LineItem;
import ru.crystals.pos.spi.receipt.Receipt;

/**
 * Интерфейс запроса на удаление позиции из чека продажи
 */
public interface RemoveFromSaleRequest {

    /**
     * Позиция, которую необходимо удалить из чека
     * @return {@link LineItem}
     */
    LineItem getLineItem();

    /**
     * Чек, из которого удаляется позиция
     * @return {@link Receipt}
     */
    Receipt getReceipt();

    /**
     * Интерфейс для оповещения кассы о возможности удаления позиции из чека продажи
     * @return {@link RemoveFromSaleCallback}
     */
    RemoveFromSaleCallback getCallback();

    /**
     * Подтверждено ли удаление товара кассиром
     * @return <tt>true</tt> если удаление подтверждено<br>
     *         <tt>false</tt> в противном случае
     * @since 0.0.44
     */
    default boolean isRemoveConfirmed() {
        return true;
    }
}
