package ru.crystals.pos.spi.plugin.payment;

import ru.crystals.pos.api.plugin.payment.Payment;

/**
 * Интерфейс для оповещения кассы о результатах выполнения запроса оплаты/отмены/возврата.
 * <p>
 * После вызова методов этого интерфейса процесс взаимодействия с плагином оплаты считается завершенным.
 */
public interface PaymentCallback {

    /**
     * Результат: запрос выполнен.
     * 
     * @param payment данные, которые необходимо сохранить в БД
     * @throws InvalidPaymentException исключение возникает, если аргумент payment содержит некорректные данные.<br>
     * <b>Данные не будут сохранены в БД кассы.</b><br>
     * Локализованное сообщение можно получить методом {@link InvalidPaymentException#getLocalizedMessage()}<br>
     * <pre>Причинами возникновения исключения могут быть:
     *   - аргумент payment == null;
     *   - payment.getSum() == null;
     *   - payment.getSum() меньше или равно нулю;
     *   - payment.getSum() больше требуемой суммы оплаты или возврата;
     *   - другие причины, по которым оплата не может быть добавлена в чек. 
     * </pre>
     * В данной ситуации рекомендуется отобразить сообщение об ошибке и,<br>если возможно, отменить транзакцию списания/начисления. 
     */
    void paymentCompleted(Payment payment) throws InvalidPaymentException;

    /**
     * Результат: запрос не выполнен.
     */
    default void paymentNotCompleted() {
        paymentNotCompleted(new Payment());
    }

    /**
     * Результат: запрос не выполнен.
     *
     * @param payment данные, которые необходимо сохранить в БД
     *
     * @since 0.0.71
     */
    void paymentNotCompleted(Payment payment);

}
